@@ -19,6 +19,8 @@
 #include "asyncresult.h"
 #include "cancellable.h"
 #include "drive.h"
+#include "emblem.h"
+#include "emblemedicon.h"
 #include "error.h"
 #include "file.h"
 #include "fileattributeinfo.h"
@@ -35,6 +37,7 @@
 #include "icon.h"
 #include "inputstream.h"
 #include "loadableicon.h"
+#include "memoryoutputstream.h"
 #include "mount.h"
 #include "mountoperation.h"
 #include "outputstream.h"
@@ -63,6 +66,8 @@ GType g_data_output_stream_get_type(void);
 #ifndef G_OS_WIN32
 GType g_desktop_app_info_get_type(void);
 #endif //G_OS_WIN32
+GType g_emblem_get_type(void);
+GType g_emblemed_icon_get_type(void);
 GType g_file_enumerator_get_type(void);
 GType g_file_icon_get_type(void);
 GType g_file_info_get_type(void);
@@ -74,6 +79,7 @@ GType g_filter_input_stream_get_type(void);
 GType g_filter_output_stream_get_type(void);
 GType g_input_stream_get_type(void);
 GType g_memory_input_stream_get_type(void);
+GType g_memory_output_stream_get_type(void);
 GType g_mount_operation_get_type(void);
 GType g_output_stream_get_type(void);
 GType g_themed_icon_get_type(void);
@@ -102,6 +108,8 @@ namespace Gio {  class DataOutputStream_Class { public: static Glib::ObjectBase*
 #ifndef G_OS_WIN32
 namespace Gio {  class DesktopAppInfo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+namespace Gio {  class Emblem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class EmblemedIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class FileInfo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -113,6 +121,7 @@ namespace Gio {  class FilterInputStream_Class { public: static Glib::ObjectBase
 namespace Gio {  class FilterOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class InputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MemoryInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class MemoryOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MountOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class ThemedIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -141,6 +150,8 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_desktop_app_info_get_type(), &Gio::DesktopAppInfo_Class::wrap_new);
 #endif //G_OS_WIN32
+  Glib::wrap_register(g_emblem_get_type(), &Gio::Emblem_Class::wrap_new);
+  Glib::wrap_register(g_emblemed_icon_get_type(), &Gio::EmblemedIcon_Class::wrap_new);
   Glib::wrap_register(g_file_enumerator_get_type(), &Gio::FileEnumerator_Class::wrap_new);
   Glib::wrap_register(g_file_icon_get_type(), &Gio::FileIcon_Class::wrap_new);
   Glib::wrap_register(g_file_info_get_type(), &Gio::FileInfo_Class::wrap_new);
@@ -152,6 +163,7 @@ void wrap_init()
   Glib::wrap_register(g_filter_output_stream_get_type(), &Gio::FilterOutputStream_Class::wrap_new);
   Glib::wrap_register(g_input_stream_get_type(), &Gio::InputStream_Class::wrap_new);
   Glib::wrap_register(g_memory_input_stream_get_type(), &Gio::MemoryInputStream_Class::wrap_new);
+  Glib::wrap_register(g_memory_output_stream_get_type(), &Gio::MemoryOutputStream_Class::wrap_new);
   Glib::wrap_register(g_mount_operation_get_type(), &Gio::MountOperation_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
   Glib::wrap_register(g_themed_icon_get_type(), &Gio::ThemedIcon_Class::wrap_new);
@@ -173,6 +185,8 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::DesktopAppInfo::get_type();
 #endif //G_OS_WIN32
+  Gio::Emblem::get_type();
+  Gio::EmblemedIcon::get_type();
   Gio::FileEnumerator::get_type();
   Gio::FileIcon::get_type();
   Gio::FileInfo::get_type();
@@ -184,6 +198,7 @@ void wrap_init()
   Gio::FilterOutputStream::get_type();
   Gio::InputStream::get_type();
   Gio::MemoryInputStream::get_type();
+  Gio::MemoryOutputStream::get_type();
   Gio::MountOperation::get_type();
   Gio::OutputStream::get_type();
   Gio::ThemedIcon::get_type();
