@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_MAIN_H
 #define _GLIBMM_MAIN_H
 
-/* $Id: main.h 749 2008-12-10 14:23:33Z jjongsma $ */
+/* $Id: main.h 750 2008-12-12 01:09:55Z jjongsma $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -160,6 +160,20 @@ public:
   sigc::connection connect(const sigc::slot<bool>& slot, unsigned int interval,
                            int priority = PRIORITY_DEFAULT);
 
+ /** Connects an timeout handler that runs only once.
+  * This method takes a function pointer to a function with a void return
+  * and no parameters. After running once it is not called again.
+  *
+  * @see connect
+  * @param slot A slot to call when @a interval has elapsed. For example:
+  * @code
+  * void on_timeout_once()
+  * @endcode
+  * @param interval The timeout in milliseconds.
+  * @param priority The priority of the new event source. 
+  */
+  void connect_once(const sigc::slot<void>& slot, unsigned int interval,
+                    int priority = PRIORITY_DEFAULT);
 
   /** Connects a timeout handler with whole second granularity.
    *
@@ -191,6 +205,23 @@ public:
   sigc::connection connect_seconds(const sigc::slot<bool>& slot, unsigned int interval,
                            int priority = PRIORITY_DEFAULT);
 
+ /** Connects an timeout handler that runs only once with whole second
+  *  granularity.
+  *
+  * This method takes a function pointer to a function with a void return
+  * and no parameters. After running once it is not called again.
+  *
+  * @see connect_seconds
+  * @param slot A slot to call when @a interval has elapsed. For example:
+  * @code
+  * void on_timeout_once()
+  * @endcode
+  * @param interval The timeout in milliseconds.
+  * @param priority The priority of the new event source. 
+  */
+  void connect_seconds_once(const sigc::slot<void>& slot, unsigned int interval,
+                            int priority = PRIORITY_DEFAULT);
+
 private:
   GMainContext* context_;
 
@@ -222,6 +253,12 @@ public:
    */
   sigc::connection connect(const sigc::slot<bool>& slot, int priority = PRIORITY_DEFAULT_IDLE);
 
+ /** Connects an idle handler that runs only once.
+  * This method takes a function pointer to a function with a void return
+  * and no parameters. After running once it is not called again.
+  */
+  void connect_once(const sigc::slot<void>& slot, int priority = PRIORITY_DEFAULT_IDLE);
+
 private:
   GMainContext* context_;
 
