@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: timer.cc 2 2003-01-07 16:59:16Z murrayc $ */
+/* $Id: timer.cc 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* timer.cc
  *
@@ -20,7 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gtimer.h>
+#include <glib.h>
 #include <glibmm/timer.h>
 
 
