@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h 741 2008-10-20 14:36:25Z murrayc $ */
+/* $Id: ustring.h 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -21,8 +21,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gmacros.h>
-#include <glib/gunicode.h>
+#include <glib.h>
 #include <glibmm/unicode.h>
 
 #include <iosfwd>
